@@ -9,6 +9,12 @@ systime <- function(){
     s1a <- gsub( ":" , "" , gsub( " " , "_" , s1a ) )
     res <- c(res , s1a )
     res <- c(res , paste0( substring( s1a , 1,13) , "00"  ) )
+	t1 <- gsub(":" , "" , gsub( " " , "_" , gsub( "-" , "" , res[1] ) ) )
+	res <- c( res , t1 )
+	t1 <- gsub( "_" , "" , res[ length(res) ] )
+	res <- c( res , t1 )		
+	res <- c( res , paste0( Sys.info()["nodename"] , "_" , res[ length(res) ] ) )
+	
     return(res)
         }
 ########################################################################
